pub struct AcPredBuffer { /* private fields */ }Implementations
Sourceimpl AcPredBuffer
impl AcPredBuffer
pub fn new(mb_w: usize, mb_h: usize) -> Self
Sourcepub fn pred_row(&self, mb_row: usize, mb_col: usize, blk: usize) -> [i32; 7]
pub fn pred_row(&self, mb_row: usize, mb_col: usize, blk: usize) -> [i32; 7]
Get the AC predictor row (indices 1..7 of the reconstructed block). Returns the first row of the left neighbour (for horizontal prediction).
Sourcepub fn pred_col(&self, mb_row: usize, mb_col: usize, blk: usize) -> [i32; 7]
pub fn pred_col(&self, mb_row: usize, mb_col: usize, blk: usize) -> [i32; 7]
Get the AC predictor column (rows 1..7 of the reconstructed block). Returns the first column of the top neighbour (for vertical prediction).
pub fn store_row( &mut self, mb_row: usize, mb_col: usize, blk: usize, row: [i32; 7], )
pub fn store_col( &mut self, mb_row: usize, mb_col: usize, blk: usize, col: [i32; 7], )